@@ -8,7 +8,7 @@
 ;; Keywords: matching
 ;; License: GPL3+
 ;; URL: https://dataswamp.org/~incal/elpa/wrap-search.el
-;; Version: 4.16.17
+;; Version: 4.16.19
 ;;
 ;; This file is part of GNU Emacs.
 ;;
@@ -54,7 +54,7 @@
 ;; they do,
 ;;
 ;;         C-u C-s  do case-sensitive search
-;;     C-u C-u C-s  do revere search, direction north from point
+;;     C-u C-u C-s  do reverse search, direction north from point
 ;; C-u C-u C-u C-s  do case-sensitive, reverse search
 ;;
 ;; and for `wrap-search-again', using a corresponding interface
@@ -70,11 +70,6 @@
 ;;
 ;;; Code:
 
-(defcustom wrap-search-echo-point nil
-  "Whether to echo point after a search hit."
-  :group 'wrap-search
-  :type  'boolean)
-
 (let ((prev-str "dummy search string")
       (prev-case)
       (prev-rev)
@@ -140,15 +135,12 @@ Do \\[wrap-search-again] to repeat, with `wrap-search-again'."
                          (list #'search-backward end beg)
                        (list #'search-forward beg end))))
           (if (funcall search-f str search-end t)
-              (when wrap-search-echo-point
-                (message "hit: %s" (point)))
+              (message "hit: %s" (point))
             (goto-char search-beg)
             (if (funcall search-f str (+ pos (if rev 0 (length str))) t)
                 (if (= pos (point))
                     (message "this is the only occurrence")
-                  (message "wrap%s" (if wrap-search-echo-point
-                                        (format ": %s" (point))
-                                      "")))
+                  (message "wrap: %s" (point)))
               (goto-char pos)
               (message "no hit")))))))
   (declare-function wrap-search nil))
